mocks

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2025 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IWebSocketChannel

type IWebSocketChannel struct {
	mock.Mock
}

IWebSocketChannel is an autogenerated mock type for the IWebSocketChannel type

func NewIWebSocketChannel

func NewIWebSocketChannel(t interface {
	mock.TestingT
	Cleanup(func())
}) *IWebSocketChannel

NewIWebSocketChannel creates a new instance of IWebSocketChannel. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*IWebSocketChannel) Close

func (_m *IWebSocketChannel) Close() error

Close provides a mock function with no fields

func (*IWebSocketChannel) EXPECT

func (*IWebSocketChannel) GetChannelToken

func (_m *IWebSocketChannel) GetChannelToken() string

GetChannelToken provides a mock function with no fields

func (*IWebSocketChannel) GetStreamURL

func (_m *IWebSocketChannel) GetStreamURL() string

GetStreamURL provides a mock function with no fields

func (*IWebSocketChannel) Open

func (_m *IWebSocketChannel) Open() error

Open provides a mock function with no fields

func (*IWebSocketChannel) ReadMessage added in v0.2.0

func (_m *IWebSocketChannel) ReadMessage() ([]byte, error)

ReadMessage provides a mock function with no fields

func (*IWebSocketChannel) SendMessage

func (_m *IWebSocketChannel) SendMessage(input []byte, inputType int) error

SendMessage provides a mock function with given fields: input, inputType

func (*IWebSocketChannel) SetChannelToken

func (_m *IWebSocketChannel) SetChannelToken(channelToken string)

SetChannelToken provides a mock function with given fields: channelToken

type IWebSocketChannel_Close_Call

type IWebSocketChannel_Close_Call struct {
	*mock.Call
}

IWebSocketChannel_Close_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Close'

func (*IWebSocketChannel_Close_Call) Return

func (*IWebSocketChannel_Close_Call) Run

func (*IWebSocketChannel_Close_Call) RunAndReturn

func (_c *IWebSocketChannel_Close_Call) RunAndReturn(run func() error) *IWebSocketChannel_Close_Call

type IWebSocketChannel_Expecter

type IWebSocketChannel_Expecter struct {
	// contains filtered or unexported fields
}

func (*IWebSocketChannel_Expecter) Close

Close is a helper method to define mock.On call

func (*IWebSocketChannel_Expecter) GetChannelToken

GetChannelToken is a helper method to define mock.On call

func (*IWebSocketChannel_Expecter) GetStreamURL

GetStreamURL is a helper method to define mock.On call

func (*IWebSocketChannel_Expecter) Open

Open is a helper method to define mock.On call

func (*IWebSocketChannel_Expecter) ReadMessage added in v0.2.0

ReadMessage is a helper method to define mock.On call

func (*IWebSocketChannel_Expecter) SendMessage

func (_e *IWebSocketChannel_Expecter) SendMessage(input interface{}, inputType interface{}) *IWebSocketChannel_SendMessage_Call

SendMessage is a helper method to define mock.On call

  • input []byte
  • inputType int

func (*IWebSocketChannel_Expecter) SetChannelToken

func (_e *IWebSocketChannel_Expecter) SetChannelToken(channelToken interface{}) *IWebSocketChannel_SetChannelToken_Call

SetChannelToken is a helper method to define mock.On call

  • channelToken string

type IWebSocketChannel_GetChannelToken_Call

type IWebSocketChannel_GetChannelToken_Call struct {
	*mock.Call
}

IWebSocketChannel_GetChannelToken_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetChannelToken'

func (*IWebSocketChannel_GetChannelToken_Call) Return

func (*IWebSocketChannel_GetChannelToken_Call) Run

func (*IWebSocketChannel_GetChannelToken_Call) RunAndReturn

type IWebSocketChannel_GetStreamURL_Call

type IWebSocketChannel_GetStreamURL_Call struct {
	*mock.Call
}

IWebSocketChannel_GetStreamURL_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'GetStreamURL'

func (*IWebSocketChannel_GetStreamURL_Call) Return

func (*IWebSocketChannel_GetStreamURL_Call) Run

func (*IWebSocketChannel_GetStreamURL_Call) RunAndReturn

type IWebSocketChannel_Open_Call

type IWebSocketChannel_Open_Call struct {
	*mock.Call
}

IWebSocketChannel_Open_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'Open'

func (*IWebSocketChannel_Open_Call) Return

func (*IWebSocketChannel_Open_Call) Run

func (*IWebSocketChannel_Open_Call) RunAndReturn

func (_c *IWebSocketChannel_Open_Call) RunAndReturn(run func() error) *IWebSocketChannel_Open_Call

type IWebSocketChannel_ReadMessage_Call added in v0.2.0

type IWebSocketChannel_ReadMessage_Call struct {
	*mock.Call
}

IWebSocketChannel_ReadMessage_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'ReadMessage'

func (*IWebSocketChannel_ReadMessage_Call) Return added in v0.2.0

func (*IWebSocketChannel_ReadMessage_Call) Run added in v0.2.0

func (*IWebSocketChannel_ReadMessage_Call) RunAndReturn added in v0.2.0

type IWebSocketChannel_SendMessage_Call

type IWebSocketChannel_SendMessage_Call struct {
	*mock.Call
}

IWebSocketChannel_SendMessage_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SendMessage'

func (*IWebSocketChannel_SendMessage_Call) Return

func (*IWebSocketChannel_SendMessage_Call) Run

func (_c *IWebSocketChannel_SendMessage_Call) Run(run func(input []byte, inputType int)) *IWebSocketChannel_SendMessage_Call

func (*IWebSocketChannel_SendMessage_Call) RunAndReturn

type IWebSocketChannel_SetChannelToken_Call

type IWebSocketChannel_SetChannelToken_Call struct {
	*mock.Call
}

IWebSocketChannel_SetChannelToken_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'SetChannelToken'

func (*IWebSocketChannel_SetChannelToken_Call) Return

func (*IWebSocketChannel_SetChannelToken_Call) Run

func (*IWebSocketChannel_SetChannelToken_Call) RunAndReturn

Jump to