executor

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 18, 2025 License: Apache-2.0 Imports: 19 Imported by: 0

Documentation

Overview

Package executor implements ECS task execution and session management.

Index

Constants

This section is empty.

Variables

var (
	// ErrInvalidARN indicates that the provided ARN is invalid.
	ErrInvalidARN = errors.New("invalid ARN")

	// ErrInvalidSessionType indicates that the provided session type is invalid.
	ErrInvalidSessionType = errors.New("invalid session type")
)

Functions

This section is empty.

Types

type Executor

type Executor struct {
	// contains filtered or unexported fields
}

Executor manages ECS task execution and session management.

func NewExecutor

func NewExecutor(ecsClient *ecs.Client, kmsClient *kms.Client, ssmClient *ssm.Client, logger log.T) *Executor

NewExecutor creates a new Executor instance with the provided AWS clients and logger.

func NewFromConfig

func NewFromConfig(cfg aws.Config, logger log.T) *Executor

NewFromConfig creates a new Executor instance using the provided AWS configuration and logger.

func (*Executor) PortForwardSession added in v0.2.0

func (e *Executor) PortForwardSession(ctx context.Context, options *PortForwardSessionOptions) error

PortForwardSession starts a port forwarding session with the provided options.

func (*Executor) ShellSession added in v0.2.0

func (e *Executor) ShellSession(ctx context.Context, options *ShellSessionOptions) error

ShellSession starts a shell session with the provided options.

type PortForwardSessionOptions added in v0.2.0

type PortForwardSessionOptions struct {
	ClusterName        string
	TaskARN            string
	ContainerRuntimeID string
	Host               string
	PortNumber         int
	LocalPortNumber    int
}

PortForwardSessionOptions contains the configuration options for port forwarding sessions.

type ShellSessionOptions added in v0.2.0

type ShellSessionOptions struct {
	ClusterName        string
	TaskARN            string
	ContainerName      string
	ContainerRuntimeID string
	Command            string
}

ShellSessionOptions contains the configuration options for executing a shell session.

Jump to