service

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 2, 2025 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Overview

Package service is a wrapper for the new Service

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type OpenDataChannelInput

type OpenDataChannelInput struct {

	// MessageSchemaVersion is a required field
	MessageSchemaVersion *string `json:"MessageSchemaVersion" min:"1" required:"true" type:"string"`

	// RequestID is a required field
	RequestID *string `json:"RequestId" min:"16" required:"true" type:"string"`

	// TokenValue is a required field
	TokenValue *string `json:"TokenValue" min:"1" required:"true" type:"string"`

	// ClientID is a required field
	ClientID *string `json:"ClientId" min:"1" required:"true" type:"string"`

	// ClientVersion is a required field
	ClientVersion *string `json:"ClientVersion" min:"1" required:"true" type:"string"`
	// contains filtered or unexported fields
}

OpenDataChannelInput represents the input parameters for opening a data channel.

Jump to