Documentation
¶
Overview ¶
Package executor implements ECS task execution and session management.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // ErrInvalidARN indicates that the provided ARN is invalid. ErrInvalidARN = errors.New("invalid ARN") // ErrInvalidSessionType indicates that the provided session type is invalid. ErrInvalidSessionType = errors.New("invalid session type") )
Functions ¶
This section is empty.
Types ¶
type Executor ¶
type Executor struct {
// contains filtered or unexported fields
}
Executor manages ECS task execution and session management.
func NewExecutor ¶
func NewExecutor(ecsClient *ecs.Client, kmsClient *kms.Client, ssmClient *ssm.Client, logger log.T) *Executor
NewExecutor creates a new Executor instance with the provided AWS clients and logger.
func NewFromConfig ¶
NewFromConfig creates a new Executor instance using the provided AWS configuration and logger.
func (*Executor) PortForwardSession ¶ added in v0.2.0
func (e *Executor) PortForwardSession(ctx context.Context, options *PortForwardSessionOptions) error
PortForwardSession starts a port forwarding session with the provided options.
func (*Executor) ShellSession ¶ added in v0.2.0
func (e *Executor) ShellSession(ctx context.Context, options *ShellSessionOptions) error
ShellSession starts a shell session with the provided options.
Click to show internal directories.
Click to hide internal directories.