Documentation
¶
Overview ¶
Package version contains CLI version constant and utilities.
Package version contains CLI version constant and utilities.
Package version contains version constants and utilities.
Index ¶
Constants ¶
const Version = "1.3.0.0"
Version is the version of the CLI.
Variables ¶
var ErrInvalidVersion = errors.New("invalid version")
ErrInvalidVersion is returned when the version string is invalid.
var ErrLengthMismatch = errors.New("length mismatch between versions")
ErrLengthMismatch is returned when the length of two version strings do not match.
Functions ¶
func DoesAgentSupportDisableSmuxKeepAlive ¶
DoesAgentSupportDisableSmuxKeepAlive returns true if given agentVersion disables smux KeepAlive in TCP multiplexing in port plugin, false otherwise.
func DoesAgentSupportTCPMultiplexing ¶
DoesAgentSupportTCPMultiplexing returns true if given agentVersion supports TCP multiplexing in port plugin, false otherwise.
func DoesAgentSupportTerminateSessionFlag ¶
DoesAgentSupportTerminateSessionFlag returns true if given agentVersion supports TerminateSession flag, false otherwise.
Types ¶
type Number ¶
type Number struct {
// contains filtered or unexported fields
}
Number represents a semantic version number.
func NewVersion ¶
NewVersion initializes Number struct by splitting given version string into string list using separator ".".